==> jc-1.4.0.tar.gz: java/rmi/server/LogStream.h <==
// public class java.rmi.server.LogStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 75f014535cd80b2e java_io_PrintStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a6f04afc4f7fccf8 java_rmi_server_LogStream

// header file dependencies
// @dep_header java_io_PrintStream

#include "java/io/PrintStream.h"

#ifndef _JC_java_rmi_server_LogStream_H_
#define _JC_java_rmi_server_LogStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_LogStream$object;

// Typedefs
typedef struct _jc_java_rmi_server_LogStream$sub_refs	_jc_java_rmi_server_LogStream$sub_refs;
typedef struct _jc_java_rmi_server_LogStream$sub_nonrefs	_jc_java_rmi_server_LogStream$sub_nonrefs;
typedef struct _jc_java_rmi_server_LogStream$refs	_jc_java_rmi_server_LogStream$refs;
typedef struct _jc_java_rmi_server_LogStream$nonrefs	_jc_java_rmi_server_LogStream$nonrefs;
typedef struct _jc_java_rmi_server_LogStream$object	_jc_java_rmi_server_LogStream$object;

typedef struct _jc_java_rmi_server_LogStream$fields_struct	_jc_java_rmi_server_LogStream$fields_struct;
typedef const struct _jc_java_rmi_server_LogStream$vmethods	_jc_java_rmi_server_LogStream$vmethods;
typedef const struct _jc_java_rmi_server_LogStream$vtable	_jc_java_rmi_server_LogStream$vtable;
typedef const struct _jc_java_rmi_server_LogStream$vtype	_jc_java_rmi_server_LogStream$vtype;

// Class fields structure
struct _jc_java_rmi_server_LogStream$fields_struct {
	struct _jc_java_io_PrintStream$object	*defStream;
	jint	BRIEF;
	jint	SILENT;
	jint	VERBOSE;
};
extern _jc_java_rmi_server_LogStream$fields_struct _jc_java_rmi_server_LogStream$class_fields;

// Constructors
extern void _jc_java_rmi_server_LogStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern struct _jc_java_io_OutputStream$object *_jc_java_rmi_server_LogStream$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_java_rmi_server_LogStream$object *);
extern void _jc_java_rmi_server_LogStream$method$setOutputStream$1e4d75e346baf6f0(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_java_io_OutputStream$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_LogStream$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_LogStream$object *);
extern void _jc_java_rmi_server_LogStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, jint);
extern void _jc_java_rmi_server_LogStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_LogStream$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$setOutputStream$1e4d75e346baf6f0;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$write$306a698343ec27e8;

// Static methods
extern struct _jc_java_io_PrintStream$object *_jc_java_rmi_server_LogStream$method$getDefaultStream$b107c6f469d06d2d(_jc_env *);
extern struct _jc_java_rmi_server_LogStream$object *_jc_java_rmi_server_LogStream$method$log$9b84c8aaf2d24182(_jc_env *, struct _jc_java_lang_String$object *);
extern jint _jc_java_rmi_server_LogStream$method$parseLevel$3a491a7dc4faaa63(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_server_LogStream$method$setDefaultStream$40ba567858653968(_jc_env *, struct _jc_java_io_PrintStream$object *);

// Virtual methods structure
struct _jc_java_rmi_server_LogStream$vmethods {
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *);
	void	(*setOutputStream$1e4d75e346baf6f0)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_java_io_OutputStream$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_rmi_server_LogStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_io_PrintStream$vmethods	java_io_PrintStream;
	_jc_java_rmi_server_LogStream$vmethods	java_rmi_server_LogStream;
};

// Vtype
struct _jc_java_rmi_server_LogStream$vtype {
	_jc_type			type;
	_jc_java_rmi_server_LogStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_LogStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_LogStream$refs {
    _jc_java_rmi_server_LogStream$sub_refs	java_rmi_server_LogStream;
    _jc_java_io_PrintStream$sub_refs	java_io_PrintStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_LogStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_LogStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_io_PrintStream$sub_nonrefs	java_io_PrintStream;
    _jc_java_rmi_server_LogStream$sub_nonrefs	java_rmi_server_LogStream;
};

// Object instance structure
struct _jc_java_rmi_server_LogStream$object {
	_jc_java_rmi_server_LogStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_LogStream$vtype	*vtype;
	_jc_java_rmi_server_LogStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_LogStream$vtype _jc_java_rmi_server_LogStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_LogStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_LogStream$class_object;

#endif	/* _JC_java_rmi_server_LogStream_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/LogStream.h <==
// public class java.rmi.server.LogStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 99a46305ebacacb5 java_io_PrintStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a6f04afc4f7fccf8 java_rmi_server_LogStream

// header file dependencies
// @dep_header java_io_PrintStream

#include "java/io/PrintStream.h"

#ifndef _JC_java_rmi_server_LogStream_H_
#define _JC_java_rmi_server_LogStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_LogStream$object;

// Typedefs
typedef struct _jc_java_rmi_server_LogStream$sub_refs	_jc_java_rmi_server_LogStream$sub_refs;
typedef struct _jc_java_rmi_server_LogStream$sub_nonrefs	_jc_java_rmi_server_LogStream$sub_nonrefs;
typedef struct _jc_java_rmi_server_LogStream$refs	_jc_java_rmi_server_LogStream$refs;
typedef struct _jc_java_rmi_server_LogStream$nonrefs	_jc_java_rmi_server_LogStream$nonrefs;
typedef struct _jc_java_rmi_server_LogStream$object	_jc_java_rmi_server_LogStream$object;

typedef struct _jc_java_rmi_server_LogStream$fields_struct	_jc_java_rmi_server_LogStream$fields_struct;
typedef const struct _jc_java_rmi_server_LogStream$vmethods	_jc_java_rmi_server_LogStream$vmethods;
typedef const struct _jc_java_rmi_server_LogStream$vtable	_jc_java_rmi_server_LogStream$vtable;
typedef const struct _jc_java_rmi_server_LogStream$vtype	_jc_java_rmi_server_LogStream$vtype;

// Class fields structure
struct _jc_java_rmi_server_LogStream$fields_struct {
	struct _jc_java_io_PrintStream$object	*defStream;
	jint	BRIEF;
	jint	SILENT;
	jint	VERBOSE;
};
extern _jc_java_rmi_server_LogStream$fields_struct _jc_java_rmi_server_LogStream$class_fields;

// Constructors
extern void _jc_java_rmi_server_LogStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_OutputStream$object *_jc_java_rmi_server_LogStream$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_java_rmi_server_LogStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_LogStream$method$setOutputStream$1e4d75e346baf6f0(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_LogStream$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_LogStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_LogStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_LogStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_LogStream$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$setOutputStream$1e4d75e346baf6f0;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_rmi_server_LogStream$method_info$write$306a698343ec27e8;

// Static methods
extern struct _jc_java_io_PrintStream$object *_jc_java_rmi_server_LogStream$method$getDefaultStream$b107c6f469d06d2d(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_server_LogStream$object *_jc_java_rmi_server_LogStream$method$log$9b84c8aaf2d24182(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_server_LogStream$method$parseLevel$3a491a7dc4faaa63(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_LogStream$method$setDefaultStream$40ba567858653968(_jc_env *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_LogStream$vmethods {
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *) _JC_JCNI_ATTR;
	void	(*setOutputStream$1e4d75e346baf6f0)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_rmi_server_LogStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_LogStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_java_io_PrintStream$vmethods	java_io_PrintStream;
	_jc_java_rmi_server_LogStream$vmethods	java_rmi_server_LogStream;
};

// Vtype
struct _jc_java_rmi_server_LogStream$vtype {
	_jc_type			type;
	_jc_java_rmi_server_LogStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_LogStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_LogStream$refs {
    _jc_java_rmi_server_LogStream$sub_refs	java_rmi_server_LogStream;
    _jc_java_io_PrintStream$sub_refs	java_io_PrintStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_LogStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_LogStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_java_io_PrintStream$sub_nonrefs	java_io_PrintStream;
    _jc_java_rmi_server_LogStream$sub_nonrefs	java_rmi_server_LogStream;
};

// Object instance structure
struct _jc_java_rmi_server_LogStream$object {
	_jc_java_rmi_server_LogStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_LogStream$vtype	*vtype;
	_jc_java_rmi_server_LogStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_LogStream$vtype _jc_java_rmi_server_LogStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_LogStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_LogStream$class_object;

#endif	/* _JC_java_rmi_server_LogStream_H_ */
